#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    tldr.py
    ~~~~~~

    A python client for tldr: simplified and community-driven man pages.

    :copyright: (c) 2015 by lord63.
    :license: MIT, see LICENSE for more details.
"""

__title__ = "tldr.py"
__version__ = "0.3.0"
__author__ = "lord63"
__homepage__ = "https://github.com/lord63/tldr.py"
__license__ = "MIT"
__copyright__ = "Copyright 2015 lord63"
